﻿/* 
  CESYS Software License - Version 1.0 - January 1st, 2016

  Permission is hereby granted, free of charge, to any person or organization
  obtaining a copy of the software and accompanying documentation covered by
  this license (the "Software") to use, reproduce, display, distribute,
  execute, and transmit the Software, and to prepare derivative works of the
  Software, and to permit third-parties to whom the Software is furnished to
  do so, all subject to the following:

  The software must only be used to operate hardware manufactured by 
  CESYS GmbH, Herzogenaurach.

  The copyright notices in the Software and this entire statement, including
  the above license grant, this restriction and the following disclaimer,
  must be included in all copies of the Software, in whole or in part, and
  all derivative works of the Software, unless such copies or derivative
  works are solely in the form of machine-executable object code generated by
  a source language processor.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
  SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
  FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
  
  Written by Thomas Hoppe <thomas.hoppe@cesys.com>, 2016
*/  

using System;
using System.Collections.Generic;
using System.Text;

namespace CeboMsrNet
{
    /// <summary>
    /// Class that is responsible for all device independent functionality.
    /// </summary>
    public sealed class LibraryInterface
    {
        /// <summary>
        /// Version of the CeboMsr-Base-API.
        /// </summary>
        public static string ApiVersion { get { return SystemConnector.GetApiVersion(); } }

        /// <summary>
        /// Enumerate devices on this system. Already opened devices are not included.
        /// </summary>
        /// <param name="type">Type of devices to enumerate.</param>
        /// <returns>Device ready to use.</returns>
        public static IList<Device> Enumerate(DeviceType type)
        {
            List<Device> r = new List<Device>();

            for (int i = 0; i < SystemConnector.BeginEnumerate(type.InterfaceId); ++i)
            {
                uint msrType = 0;
                string version = "";
                string ident = SystemConnector.GetIdentifier(i, ref msrType, ref version);

                r.Add(new Device(ident, DeviceType.GetDeviceTypeById(msrType), version));
            }

            return r.AsReadOnly();
        }

        /// <summary>
        /// *** unofficial experimental feature, don't use ***
        /// </summary>
        public static IList<Device> EnumerateNetwork(string hostname, int port, DeviceType type)
        {
            List<Device> r = new List<Device>();

            for (int i = 0; i < SystemConnector.BeginEnumerateNetwork(hostname, port, type.InterfaceId); ++i)
            {
                uint msrType = 0;
                string version = "";
                string ident = SystemConnector.GetIdentifier(i, ref msrType, ref version);

                r.Add(new Device(ident, DeviceType.GetDeviceTypeById(msrType), version));
            }

            return r.AsReadOnly();
        }
    }
}
