/* 
  CESYS Software License - Version 1.0 - January 1st, 2016

  Permission is hereby granted, free of charge, to any person or organization
  obtaining a copy of the software and accompanying documentation covered by
  this license (the "Software") to use, reproduce, display, distribute,
  execute, and transmit the Software, and to prepare derivative works of the
  Software, and to permit third-parties to whom the Software is furnished to
  do so, all subject to the following:

  The software must only be used to operate hardware manufactured by 
  CESYS GmbH, Herzogenaurach.

  The copyright notices in the Software and this entire statement, including
  the above license grant, this restriction and the following disclaimer,
  must be included in all copies of the Software, in whole or in part, and
  all derivative works of the Software, unless such copies or derivative
  works are solely in the form of machine-executable object code generated by
  a source language processor.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
  SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
  FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
  
  Written by Thomas Hoppe <thomas.hoppe@cesys.com>, 2016
*/  

package com.cesys.cebo.cebomsr;

/**
 * Values to be used in enumeration.
 *
 * @author Thomas Hoppe
 */
public final class DeviceType {
	private final int _interfaceId;
	private final String _name;

	int getInterfaceId() {
		return _interfaceId;
	}

	/**
	 * Return instance name, "Usb", "All", ...
	 */
	public String getName() {
		return _name;
	}

	private DeviceType(int interfaceId, String name) {
		_interfaceId = interfaceId;
		_name = name;
	}

	public final static DeviceType All = new DeviceType(SystemConnector.CeboMsrTypeAll, "All");
	public final static DeviceType Usb = new DeviceType(SystemConnector.CeboMsrTypeUsb, "Usb");
	public final static DeviceType CeboLC = new DeviceType(SystemConnector.CeboMsrTypeCeboLC, "CeboLC");
	public final static DeviceType CeboStick = new DeviceType(SystemConnector.CeboMsrTypeCeboStick, "CeboStick");

	static DeviceType getDeviceTypeById(int id) {
		switch (id) {
		case SystemConnector.CeboMsrTypeAll: return All;
		case SystemConnector.CeboMsrTypeUsb: return Usb;
		case SystemConnector.CeboMsrTypeCeboLC: return CeboLC;
		case SystemConnector.CeboMsrTypeCeboStick: return CeboStick;
		}
		throw new IndexOutOfBoundsException();
	}

	public String toString() {
		return getName();
	}
}
